"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Action:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Action.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _Action.ValueType  # 0
    """"""
    UPDATE: _Action.ValueType  # 1
    """"""
    DELETE: _Action.ValueType  # 2
    """"""

class Action(_Action, metaclass=_ActionEnumTypeWrapper):
    """"""

UNKNOWN: Action.ValueType  # 0
""""""
UPDATE: Action.ValueType  # 1
""""""
DELETE: Action.ValueType  # 2
""""""
global___Action = Action

@typing_extensions.final
class AuthReq(google.protobuf.message.Message):
    """鉴权请求，通过authorization验证绑定用户mid"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GUID_FIELD_NUMBER: builtins.int
    CONN_ID_FIELD_NUMBER: builtins.int
    LAST_MSG_ID_FIELD_NUMBER: builtins.int
    guid: builtins.str
    """冷启动id，算法uuid，重新起启会变"""
    conn_id: builtins.str
    """连接id，算法uuid，重连会变"""
    last_msg_id: builtins.int
    """最后收到的消息id，用于过虑重连后获取未读的消息"""
    def __init__(
        self,
        *,
        guid: builtins.str = ...,
        conn_id: builtins.str = ...,
        last_msg_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conn_id", b"conn_id", "guid", b"guid", "last_msg_id", b"last_msg_id"]) -> None: ...

global___AuthReq = AuthReq

@typing_extensions.final
class AuthResp(google.protobuf.message.Message):
    """鉴权返回"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AuthResp = AuthResp

@typing_extensions.final
class BroadcastFrame(google.protobuf.message.Message):
    """target_path:
      "/" Service-Name "/" {method name} 参考 gRPC Request Path
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___FrameOption:
        """请求消息信息"""
    target_path: builtins.str
    """业务target_path"""
    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """业务pb内容"""
    def __init__(
        self,
        *,
        options: global___FrameOption | None = ...,
        target_path: builtins.str = ...,
        body: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body", "options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "options", b"options", "target_path", b"target_path"]) -> None: ...

global___BroadcastFrame = BroadcastFrame

@typing_extensions.final
class FrameOption(google.protobuf.message.Message):
    """message_id: 
      client: 本次连接唯一的消息id，可用于回执
      server: 唯一消息id，可用于上报或者回执
    sequence:
      client: 客户端应该每次请求时frame seq++，会返回对应的对称req/resp
      server: 服务端下行消息，只会返回默认值：0
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    IS_ACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    """消息id"""
    sequence: builtins.int
    """frame序号"""
    is_ack: builtins.bool
    """是否进行消息回执(发出MessageAckReq)
    downstream 上只有服务端设置为true，客户端响应
    upstream   上只有客户端设置为true，服务端响应
    响应帧禁止设置is_ack，协议上禁止循环
    通常只有业务帧才可能设置is_ack, 因为协议栈(例如心跳、鉴权)另有响应约定
    """
    @property
    def status(self) -> bilireq.grpc.protos.bilibili.rpc.status_pb2.Status:
        """业务状态码"""
    ack_origin: builtins.str
    """业务ack来源, 仅downstream时候由服务端填写."""
    timestamp: builtins.int
    """"""
    def __init__(
        self,
        *,
        message_id: builtins.int = ...,
        sequence: builtins.int = ...,
        is_ack: builtins.bool = ...,
        status: bilireq.grpc.protos.bilibili.rpc.status_pb2.Status | None = ...,
        ack_origin: builtins.str = ...,
        timestamp: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_origin", b"ack_origin", "is_ack", b"is_ack", "message_id", b"message_id", "sequence", b"sequence", "status", b"status", "timestamp", b"timestamp"]) -> None: ...

global___FrameOption = FrameOption

@typing_extensions.final
class HeartbeatReq(google.protobuf.message.Message):
    """心跳请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartbeatReq = HeartbeatReq

@typing_extensions.final
class HeartbeatResp(google.protobuf.message.Message):
    """心跳返回"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartbeatResp = HeartbeatResp

@typing_extensions.final
class MessageAckReq(google.protobuf.message.Message):
    """消息回执"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACK_ID_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    ack_id: builtins.int
    """消息id"""
    ack_origin: builtins.str
    """ack来源，由业务指定用于埋点跟踪"""
    target_path: builtins.str
    """消息对应的target_path，方便业务区分和监控统计"""
    def __init__(
        self,
        *,
        ack_id: builtins.int = ...,
        ack_origin: builtins.str = ...,
        target_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_id", b"ack_id", "ack_origin", b"ack_origin", "target_path", b"target_path"]) -> None: ...

global___MessageAckReq = MessageAckReq

@typing_extensions.final
class TargetPath(google.protobuf.message.Message):
    """target_path"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_PATHS_FIELD_NUMBER: builtins.int
    @property
    def target_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """需要订阅的target_paths"""
    def __init__(
        self,
        *,
        target_paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_paths", b"target_paths"]) -> None: ...

global___TargetPath = TargetPath



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CommentDoubleClickConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERACTION_FIELD_NUMBER: builtins.int
    ANIMATION_SCALE_FIELD_NUMBER: builtins.int
    @property
    def interaction(self) -> global___Interaction:
        """"""
    animation_scale: builtins.float
    """"""
    def __init__(
        self,
        *,
        interaction: global___Interaction | None = ...,
        animation_scale: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interaction", b"interaction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation_scale", b"animation_scale", "interaction", b"interaction"]) -> None: ...

global___CommentDoubleClickConfig = CommentDoubleClickConfig

@typing_extensions.final
class GyroConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GYROSCOPE_FIELD_NUMBER: builtins.int
    @property
    def gyroscope(self) -> global___NFTImageV2:
        """"""
    def __init__(
        self,
        *,
        gyroscope: global___NFTImageV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> None: ...

global___GyroConfig = GyroConfig

@typing_extensions.final
class GyroscopeContentV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_URL_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    PHYSICAL_ORIENTATION_FIELD_NUMBER: builtins.int
    file_url: builtins.str
    """"""
    scale: builtins.float
    """"""
    @property
    def physical_orientation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhysicalOrientationV2]:
        """"""
    def __init__(
        self,
        *,
        file_url: builtins.str = ...,
        scale: builtins.float = ...,
        physical_orientation: collections.abc.Iterable[global___PhysicalOrientationV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_url", b"file_url", "physical_orientation", b"physical_orientation", "scale", b"scale"]) -> None: ...

global___GyroscopeContentV2 = GyroscopeContentV2

@typing_extensions.final
class GyroscopeEntityV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_TYPE_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    display_type: builtins.str
    """"""
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GyroscopeContentV2]:
        """"""
    def __init__(
        self,
        *,
        display_type: builtins.str = ...,
        contents: collections.abc.Iterable[global___GyroscopeContentV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents", b"contents", "display_type", b"display_type"]) -> None: ...

global___GyroscopeEntityV2 = GyroscopeEntityV2

@typing_extensions.final
class Interaction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NFT_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ITYPE_FIELD_NUMBER: builtins.int
    METADATA_URL_FIELD_NUMBER: builtins.int
    nft_id: builtins.str
    """"""
    enabled: builtins.bool
    """"""
    itype: builtins.str
    """"""
    metadata_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        nft_id: builtins.str = ...,
        enabled: builtins.bool = ...,
        itype: builtins.str = ...,
        metadata_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "itype", b"itype", "metadata_url", b"metadata_url", "nft_id", b"nft_id"]) -> None: ...

global___Interaction = Interaction

@typing_extensions.final
class LiveAnimeConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVE_FIELD_NUMBER: builtins.int
    is_live: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_live: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_live", b"is_live"]) -> None: ...

global___LiveAnimeConfig = LiveAnimeConfig

@typing_extensions.final
class LiveAnimeItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    START_RATIO_FIELD_NUMBER: builtins.int
    END_RATIO_FIELD_NUMBER: builtins.int
    START_STROKE_FIELD_NUMBER: builtins.int
    START_OPACITY_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ColorConfig:
        """"""
    start_ratio: builtins.float
    """"""
    end_ratio: builtins.float
    """"""
    start_stroke: builtins.float
    """"""
    start_opacity: builtins.float
    """"""
    phase: builtins.int
    """"""
    def __init__(
        self,
        *,
        color: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ColorConfig | None = ...,
        start_ratio: builtins.float = ...,
        end_ratio: builtins.float = ...,
        start_stroke: builtins.float = ...,
        start_opacity: builtins.float = ...,
        phase: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "end_ratio", b"end_ratio", "phase", b"phase", "start_opacity", b"start_opacity", "start_ratio", b"start_ratio", "start_stroke", b"start_stroke"]) -> None: ...

global___LiveAnimeItem = LiveAnimeItem

@typing_extensions.final
class NFTImageV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GYROSCOPE_FIELD_NUMBER: builtins.int
    @property
    def gyroscope(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GyroscopeEntityV2]:
        """"""
    def __init__(
        self,
        *,
        gyroscope: collections.abc.Iterable[global___GyroscopeEntityV2] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gyroscope", b"gyroscope"]) -> None: ...

global___NFTImageV2 = NFTImageV2

@typing_extensions.final
class PhysicalOrientationAnimation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BEZIER_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    bezier: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        bezier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bezier", b"bezier", "type", b"type"]) -> None: ...

global___PhysicalOrientationAnimation = PhysicalOrientationAnimation

@typing_extensions.final
class PhysicalOrientationV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ANIMATIONS_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    @property
    def animations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhysicalOrientationAnimation]:
        """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        animations: collections.abc.Iterable[global___PhysicalOrientationAnimation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["animations", b"animations", "type", b"type"]) -> None: ...

global___PhysicalOrientationV2 = PhysicalOrientationV2



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PlayerArgs(google.protobuf.message.Message):
    """视频秒开参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    VOICE_BALANCE_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """流版本"""
    fnval: builtins.int
    """流类型"""
    force_host: builtins.int
    """返回url是否强制使用域名
    0:不强制使用域名 1:http域名 2:https域名
    """
    voice_balance: builtins.int
    """音量均衡"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        voice_balance: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "qn", b"qn", "voice_balance", b"voice_balance"]) -> None: ...

global___PlayerArgs = PlayerArgs



import os
import subprocess
from pathlib import Path

os.chdir(Path(__file__).parent.absolute() / "protos")


for file_path in Path(".").rglob("*.proto"):
    if file_path.is_file():
        subprocess.run(
            [
                "python",
                "-m",
                "grpc_tools.protoc",
                "-I=.",
                "--python_out=.",
                "--grpc_python_out=.",
                "--mypy_out=.",
                str(file_path),
            ],
            # shell=True,
        )

    for file_path in [
        file_path.with_name(f"{file_path.stem}_pb2_grpc.py"),
        file_path.with_name(f"{file_path.stem}_pb2.py"),
        file_path.with_name(f"{file_path.stem}_pb2.pyi"),
    ]:
        if file_path.is_file():
            with open(file_path, "r", encoding="utf-8") as f:
                lines = f.readlines()
            with open(file_path, "w", encoding="utf-8") as f:
                for line in lines:
                    if line.startswith("from bilibili."):
                        line = line.replace(
                            "from bilibili.", "from bilireq.grpc.protos.bilibili."
                        )
                    elif line.startswith("import bilibili."):
                        line = line.replace(
                            "import bilibili.", "import bilireq.grpc.protos.bilibili."
                        )
                    elif line.startswith("from pgc."):
                        line = line.replace("from pgc.", "from bilireq.grpc.protos.pgc.")
                    elif line.startswith("import pgc."):
                        line = line.replace("import pgc.", "import bilireq.grpc.protos.pgc.")
                    elif "-> bilibili" in line:
                        line = line.replace("-> bilibili", "-> bilireq.grpc.protos.bilibili")
                    elif ": bilibili" in line:
                        line = line.replace(": bilibili", ": bilireq.grpc.protos.bilibili")
                    f.write(line)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DanmukuEvent(google.protobuf.message.Message):
    """实时弹幕事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELEMS_FIELD_NUMBER: builtins.int
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
    def __init__(
        self,
        *,
        elems: collections.abc.Iterable[global___DanmakuElem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["elems", b"elems"]) -> None: ...

global___DanmukuEvent = DanmukuEvent

@typing_extensions.final
class DanmakuElem(google.protobuf.message.Message):
    """弹幕条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    MID_HASH_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕dmid"""
    progress: builtins.int
    """弹幕出现位置(单位为ms)"""
    mode: builtins.int
    """弹幕类型"""
    fontsize: builtins.int
    """弹幕字号"""
    color: builtins.int
    """弹幕颜色"""
    mid_hash: builtins.str
    """发送着mid hash"""
    content: builtins.str
    """弹幕正文"""
    ctime: builtins.int
    """发送时间"""
    action: builtins.str
    """弹幕动作"""
    pool: builtins.int
    """弹幕池"""
    id_str: builtins.str
    """弹幕id str"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        progress: builtins.int = ...,
        mode: builtins.int = ...,
        fontsize: builtins.int = ...,
        color: builtins.int = ...,
        mid_hash: builtins.str = ...,
        content: builtins.str = ...,
        ctime: builtins.int = ...,
        action: builtins.str = ...,
        pool: builtins.int = ...,
        id_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "color", b"color", "content", b"content", "ctime", b"ctime", "fontsize", b"fontsize", "id", b"id", "id_str", b"id_str", "mid_hash", b"mid_hash", "mode", b"mode", "pool", b"pool", "progress", b"progress"]) -> None: ...

global___DanmakuElem = DanmakuElem

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """互动弹幕"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""
    oid: builtins.int
    """对象视频cid"""
    mid: builtins.int
    """发送者mid"""
    type: builtins.int
    """"""
    command: builtins.str
    """互动弹幕指令"""
    content: builtins.str
    """互动弹幕正文"""
    state: builtins.int
    """弹幕状态"""
    progress: builtins.int
    """出现时间"""
    ctime: builtins.str
    """创建时间"""
    mtime: builtins.str
    """发布时间"""
    extra: builtins.str
    """扩展json数据"""
    idStr: builtins.str
    """弹幕id str类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        state: builtins.int = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        idStr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "idStr", b"idStr", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress", "state", b"state", "type", b"type"]) -> None: ...

global___CommandDm = CommandDm



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.ad_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Args(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    TNAME_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CONVERGE_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    up_id: builtins.int
    """"""
    up_name: builtins.str
    """"""
    rid: builtins.int
    """"""
    rname: builtins.str
    """"""
    tid: builtins.int
    """"""
    tname: builtins.str
    """"""
    track_id: builtins.str
    """"""
    state: builtins.str
    """"""
    converge_type: builtins.int
    """"""
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        up_id: builtins.int = ...,
        up_name: builtins.str = ...,
        rid: builtins.int = ...,
        rname: builtins.str = ...,
        tid: builtins.int = ...,
        tname: builtins.str = ...,
        track_id: builtins.str = ...,
        state: builtins.str = ...,
        converge_type: builtins.int = ...,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "converge_type", b"converge_type", "rid", b"rid", "rname", b"rname", "state", b"state", "tid", b"tid", "tname", b"tname", "track_id", b"track_id", "type", b"type", "up_id", b"up_id", "up_name", b"up_name"]) -> None: ...

global___Args = Args

@typing_extensions.final
class Avatar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    DEFALUT_COVER_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    type: builtins.int
    """"""
    event: builtins.str
    """"""
    event_v2: builtins.str
    """"""
    defalut_cover: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        text: builtins.str = ...,
        uri: builtins.str = ...,
        type: builtins.int = ...,
        event: builtins.str = ...,
        event_v2: builtins.str = ...,
        defalut_cover: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "defalut_cover", b"defalut_cover", "event", b"event", "event_v2", b"event_v2", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___Avatar = Avatar

@typing_extensions.final
class Base(google.protobuf.message.Message):
    """条目基本信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_TYPE_FIELD_NUMBER: builtins.int
    CARD_GOTO_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    THREE_POINT_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    IDX_FIELD_NUMBER: builtins.int
    AD_INFO_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    THREE_POINT_V2_FIELD_NUMBER: builtins.int
    THREE_POINT_V3_FIELD_NUMBER: builtins.int
    DESC_BUTTON_FIELD_NUMBER: builtins.int
    THREE_POINT_V4_FIELD_NUMBER: builtins.int
    UP_ARGS_FIELD_NUMBER: builtins.int
    card_type: builtins.str
    """卡片类型"""
    card_goto: builtins.str
    """卡片跳转类型?"""
    goto: builtins.str
    """跳转类型
    av:视频稿件 mid:用户空间
    """
    param: builtins.str
    """目标参数"""
    cover: builtins.str
    """封面url"""
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转uri"""
    @property
    def three_point(self) -> global___ThreePoint:
        """"""
    @property
    def args(self) -> global___Args:
        """"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """"""
    idx: builtins.int
    """条目排位序号"""
    @property
    def ad_info(self) -> bilireq.grpc.protos.bilibili.app.card.v1.ad_pb2.AdInfo:
        """"""
    @property
    def mask(self) -> global___Mask:
        """"""
    from_type: builtins.str
    """来源标识
    recommend:推荐 operation:管理?
    """
    @property
    def three_point_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointV2]:
        """"""
    @property
    def three_point_v3(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointV3]:
        """"""
    @property
    def desc_button(self) -> global___Button:
        """"""
    @property
    def three_point_v4(self) -> global___ThreePointV4:
        """三点v4"""
    @property
    def up_args(self) -> global___UpArgs:
        """"""
    def __init__(
        self,
        *,
        card_type: builtins.str = ...,
        card_goto: builtins.str = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        three_point: global___ThreePoint | None = ...,
        args: global___Args | None = ...,
        player_args: global___PlayerArgs | None = ...,
        idx: builtins.int = ...,
        ad_info: bilireq.grpc.protos.bilibili.app.card.v1.ad_pb2.AdInfo | None = ...,
        mask: global___Mask | None = ...,
        from_type: builtins.str = ...,
        three_point_v2: collections.abc.Iterable[global___ThreePointV2] | None = ...,
        three_point_v3: collections.abc.Iterable[global___ThreePointV3] | None = ...,
        desc_button: global___Button | None = ...,
        three_point_v4: global___ThreePointV4 | None = ...,
        up_args: global___UpArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_info", b"ad_info", "args", b"args", "desc_button", b"desc_button", "mask", b"mask", "player_args", b"player_args", "three_point", b"three_point", "three_point_v4", b"three_point_v4", "up_args", b"up_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_info", b"ad_info", "args", b"args", "card_goto", b"card_goto", "card_type", b"card_type", "cover", b"cover", "desc_button", b"desc_button", "from_type", b"from_type", "goto", b"goto", "idx", b"idx", "mask", b"mask", "param", b"param", "player_args", b"player_args", "three_point", b"three_point", "three_point_v2", b"three_point_v2", "three_point_v3", b"three_point_v3", "three_point_v4", b"three_point_v4", "title", b"title", "up_args", b"up_args", "uri", b"uri"]) -> None: ...

global___Base = Base

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """按钮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    param: builtins.str
    """参数"""
    uri: builtins.str
    """"""
    event: builtins.str
    """事件"""
    selected: builtins.int
    """"""
    type: builtins.int
    """类型"""
    event_v2: builtins.str
    """事件v2"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        event: builtins.str = ...,
        selected: builtins.int = ...,
        type: builtins.int = ...,
        event_v2: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "event_v2", b"event_v2", "param", b"param", "relation", b"relation", "selected", b"selected", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___Button = Button

@typing_extensions.final
class DislikeReason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___DislikeReason = DislikeReason

@typing_extensions.final
class LikeButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    Aid: builtins.int
    """"""
    count: builtins.int
    """"""
    show_count: builtins.bool
    """"""
    event: builtins.str
    """"""
    selected: builtins.int
    """"""
    event_v2: builtins.str
    """"""
    def __init__(
        self,
        *,
        Aid: builtins.int = ...,
        count: builtins.int = ...,
        show_count: builtins.bool = ...,
        event: builtins.str = ...,
        selected: builtins.int = ...,
        event_v2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Aid", b"Aid", "count", b"count", "event", b"event", "event_v2", b"event_v2", "selected", b"selected", "show_count", b"show_count"]) -> None: ...

global___LikeButton = LikeButton

@typing_extensions.final
class Mask(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVATAR_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    @property
    def avatar(self) -> global___Avatar:
        """"""
    @property
    def button(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        avatar: global___Avatar | None = ...,
        button: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "button", b"button"]) -> None: ...

global___Mask = Mask

@typing_extensions.final
class PlayerArgs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    is_live: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    sub_type: builtins.int
    """"""
    room_id: builtins.int
    """"""
    ep_id: builtins.int
    """"""
    is_preview: builtins.int
    """"""
    type: builtins.str
    """"""
    duration: builtins.int
    """"""
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_live: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        sub_type: builtins.int = ...,
        room_id: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_preview: builtins.int = ...,
        type: builtins.str = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "duration", b"duration", "ep_id", b"ep_id", "is_live", b"is_live", "is_preview", b"is_preview", "room_id", b"room_id", "season_id", b"season_id", "sub_type", b"sub_type", "type", b"type"]) -> None: ...

global___PlayerArgs = PlayerArgs

@typing_extensions.final
class ReasonStyle(google.protobuf.message.Message):
    """标签框信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ICON_NIGHT_URL_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_BG_URL_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    RIGHT_ICON_TYPE_FIELD_NUMBER: builtins.int
    LEFT_ICON_TYPE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    text_color: builtins.str
    """文字颜色"""
    bg_color: builtins.str
    """背景色"""
    border_color: builtins.str
    """边框色"""
    icon_url: builtins.str
    """图标url"""
    text_color_night: builtins.str
    """文字颜色-夜间"""
    bg_color_night: builtins.str
    """背景色-夜间"""
    border_color_night: builtins.str
    """边框色-夜间"""
    icon_night_url: builtins.str
    """图标url-夜间"""
    bg_style: builtins.int
    """背景风格id
    1:无背景 2:有背景
    """
    uri: builtins.str
    """"""
    icon_bg_url: builtins.str
    """"""
    event: builtins.str
    """"""
    event_v2: builtins.str
    """"""
    right_icon_type: builtins.int
    """"""
    left_icon_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_color: builtins.str = ...,
        border_color: builtins.str = ...,
        icon_url: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color_night: builtins.str = ...,
        icon_night_url: builtins.str = ...,
        bg_style: builtins.int = ...,
        uri: builtins.str = ...,
        icon_bg_url: builtins.str = ...,
        event: builtins.str = ...,
        event_v2: builtins.str = ...,
        right_icon_type: builtins.int = ...,
        left_icon_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "event", b"event", "event_v2", b"event_v2", "icon_bg_url", b"icon_bg_url", "icon_night_url", b"icon_night_url", "icon_url", b"icon_url", "left_icon_type", b"left_icon_type", "right_icon_type", b"right_icon_type", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night", "uri", b"uri"]) -> None: ...

global___ReasonStyle = ReasonStyle

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关系信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态"""
    is_follow: builtins.int
    """是否关注"""
    is_followed: builtins.int
    """是否粉丝"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class SharePlane(google.protobuf.message.Message):
    """分享面板信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ShareToEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bool
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SHARE_TO_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_ID_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    PLAY_NUMBER_FIELD_NUMBER: builtins.int
    FIRST_CID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    share_subtitle: builtins.str
    """副标贴文案"""
    desc: builtins.str
    """备注"""
    cover: builtins.str
    """封面url"""
    aid: builtins.int
    """稿件avid"""
    bvid: builtins.str
    """稿件bvid"""
    @property
    def share_to(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bool]:
        """允许分享方式"""
    author: builtins.str
    """UP主昵称"""
    author_id: builtins.int
    """UP主mid"""
    short_link: builtins.str
    """短连接"""
    play_number: builtins.str
    """播放次数文案"""
    first_cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        share_subtitle: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        share_to: collections.abc.Mapping[builtins.str, builtins.bool] | None = ...,
        author: builtins.str = ...,
        author_id: builtins.int = ...,
        short_link: builtins.str = ...,
        play_number: builtins.str = ...,
        first_cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "author_id", b"author_id", "bvid", b"bvid", "cover", b"cover", "desc", b"desc", "first_cid", b"first_cid", "play_number", b"play_number", "share_subtitle", b"share_subtitle", "share_to", b"share_to", "short_link", b"short_link", "title", b"title"]) -> None: ...

global___SharePlane = SharePlane

@typing_extensions.final
class ThreePoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISLIKE_REASONS_FIELD_NUMBER: builtins.int
    FEEDBACKS_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def dislike_reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    @property
    def feedbacks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    watch_later: builtins.int
    """稍后再看"""
    def __init__(
        self,
        *,
        dislike_reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        feedbacks: collections.abc.Iterable[global___DislikeReason] | None = ...,
        watch_later: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_reasons", b"dislike_reasons", "feedbacks", b"feedbacks", "watch_later", b"watch_later"]) -> None: ...

global___ThreePoint = ThreePoint

@typing_extensions.final
class ThreePointV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    type: builtins.str
    """"""
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        type: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "reasons", b"reasons", "subtitle", b"subtitle", "title", b"title", "type", b"type"]) -> None: ...

global___ThreePointV2 = ThreePointV2

@typing_extensions.final
class ThreePointV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SELECTED_ICON_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DEFAULT_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    selected_title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    type: builtins.str
    """"""
    id: builtins.int
    """"""
    selected: builtins.int
    """"""
    icon: builtins.str
    """"""
    selected_icon: builtins.str
    """"""
    url: builtins.str
    """"""
    default_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        selected_title: builtins.str = ...,
        subtitle: builtins.str = ...,
        reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        type: builtins.str = ...,
        id: builtins.int = ...,
        selected: builtins.int = ...,
        icon: builtins.str = ...,
        selected_icon: builtins.str = ...,
        url: builtins.str = ...,
        default_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_id", b"default_id", "icon", b"icon", "id", b"id", "reasons", b"reasons", "selected", b"selected", "selected_icon", b"selected_icon", "selected_title", b"selected_title", "subtitle", b"subtitle", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___ThreePointV3 = ThreePointV3

@typing_extensions.final
class ThreePointV4(google.protobuf.message.Message):
    """三点v4"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_PLANE_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def share_plane(self) -> global___SharePlane:
        """分享面板信息"""
    @property
    def watch_later(self) -> global___WatchLater:
        """稍后再看"""
    def __init__(
        self,
        *,
        share_plane: global___SharePlane | None = ...,
        watch_later: global___WatchLater | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_plane", b"share_plane", "watch_later", b"watch_later"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_plane", b"share_plane", "watch_later", b"watch_later"]) -> None: ...

global___ThreePointV4 = ThreePointV4

@typing_extensions.final
class Up(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    DESC_BUTTON_FIELD_NUMBER: builtins.int
    COOPERATION_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def avatar(self) -> global___Avatar:
        """"""
    official_icon: builtins.int
    """"""
    @property
    def desc_button(self) -> global___Button:
        """"""
    cooperation: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        avatar: global___Avatar | None = ...,
        official_icon: builtins.int = ...,
        desc_button: global___Button | None = ...,
        cooperation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "desc_button", b"desc_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "cooperation", b"cooperation", "desc", b"desc", "desc_button", b"desc_button", "id", b"id", "name", b"name", "official_icon", b"official_icon"]) -> None: ...

global___Up = Up

@typing_extensions.final
class UpArgs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_ID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    UP_FACE_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    up_id: builtins.int
    """"""
    up_name: builtins.str
    """"""
    up_face: builtins.str
    """"""
    selected: builtins.int
    """"""
    def __init__(
        self,
        *,
        up_id: builtins.int = ...,
        up_name: builtins.str = ...,
        up_face: builtins.str = ...,
        selected: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["selected", b"selected", "up_face", b"up_face", "up_id", b"up_id", "up_name", b"up_name"]) -> None: ...

global___UpArgs = UpArgs

@typing_extensions.final
class WatchLater(google.protobuf.message.Message):
    """稍后再看信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    bvid: builtins.str
    """稿件bvid"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid"]) -> None: ...

global___WatchLater = WatchLater



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetUserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_URL_FIELD_NUMBER: builtins.int
    EXTRA_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def type_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def extra_context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        type_url: collections.abc.Iterable[builtins.str] | None = ...,
        extra_context: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra_context", b"extra_context", "type_url", b"type_url"]) -> None: ...

global___GetUserPreferenceReq = GetUserPreferenceReq

@typing_extensions.final
class GetUserPreferenceReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """对应 GetUserPreferenceReq 的请求的类型"""
    def __init__(
        self,
        *,
        value: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___GetUserPreferenceReply = GetUserPreferenceReply

@typing_extensions.final
class SetUserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PREFERENCE_FIELD_NUMBER: builtins.int
    EXTRA_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def preference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """"""
    @property
    def extra_context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        preference: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        extra_context: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra_context", b"extra_context", "preference", b"preference"]) -> None: ...

global___SetUserPreferenceReq = SetUserPreferenceReq

@typing_extensions.final
class SetUserPreferenceReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetUserPreferenceReply = SetUserPreferenceReply

@typing_extensions.final
class UserPreferenceReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserPreferenceReq = UserPreferenceReq

@typing_extensions.final
class UserPreferenceReply(google.protobuf.message.Message):
    """云控配置下发"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERENCE_FIELD_NUMBER: builtins.int
    @property
    def preference(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """具体解码需要根据实际请求 type_url 来判断"""
    def __init__(
        self,
        *,
        preference: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["preference", b"preference"]) -> None: ...

global___UserPreferenceReply = UserPreferenceReply

@typing_extensions.final
class BoolValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.bool
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.bool
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.bool = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___BoolValue = BoolValue

@typing_extensions.final
class BytesValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.bytes
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.bytes
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.bytes = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.bytes = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___BytesValue = BytesValue

@typing_extensions.final
class DoubleValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.float
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.float
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.float = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.float = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___DoubleValue = DoubleValue

@typing_extensions.final
class FloatValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.float
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.float
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.float = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.float = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___FloatValue = FloatValue

@typing_extensions.final
class Int32Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___Int32Value = Int32Value

@typing_extensions.final
class Int64Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___Int64Value = Int64Value

@typing_extensions.final
class StringValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.str
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.str
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.str = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___StringValue = StringValue

@typing_extensions.final
class UInt32Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___UInt32Value = UInt32Value

@typing_extensions.final
class UInt64Value(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    EXP_FIELD_NUMBER: builtins.int
    value: builtins.int
    """"""
    last_modified: builtins.int
    """"""
    default_value: builtins.int
    """"""
    exp: builtins.str
    """"""
    def __init__(
        self,
        *,
        value: builtins.int = ...,
        last_modified: builtins.int = ...,
        default_value: builtins.int = ...,
        exp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "exp", b"exp", "last_modified", b"last_modified", "value", b"value"]) -> None: ...

global___UInt64Value = UInt64Value



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetTicketRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bytes
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTEXT_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bytes]:
        """包含: 
        + x-fingerprint(包含手机各类信息, 使用 datacenter.hakase.protobuf.AndroidDeviceInfo 生成)
        + x-exbadbasket(?)
        """
    key_id: builtins.str
    """暂时固定为 ec01"""
    sign: builtins.bytes
    """"""
    token: builtins.str
    """暂时留空"""
    def __init__(
        self,
        *,
        context: collections.abc.Mapping[builtins.str, builtins.bytes] | None = ...,
        key_id: builtins.str = ...,
        sign: builtins.bytes = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "key_id", b"key_id", "sign", b"sign", "token", b"token"]) -> None: ...

global___GetTicketRequest = GetTicketRequest

@typing_extensions.final
class GetTicketResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Context(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        V_VOUCHER_FIELD_NUMBER: builtins.int
        v_voucher: builtins.str
        """"""
        def __init__(
            self,
            *,
            v_voucher: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["v_voucher", b"v_voucher"]) -> None: ...

    TICKET_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    ticket: builtins.str
    """x-bili-ticket"""
    created_at: builtins.int
    """有效期起"""
    ttl: builtins.int
    """有效期"""
    @property
    def context(self) -> global___GetTicketResponse.Context:
        """"""
    def __init__(
        self,
        *,
        ticket: builtins.str = ...,
        created_at: builtins.int = ...,
        ttl: builtins.int = ...,
        context: global___GetTicketResponse.Context | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "created_at", b"created_at", "ticket", b"ticket", "ttl", b"ttl"]) -> None: ...

global___GetTicketResponse = GetTicketResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/common/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/dynamic/common/dynamic.proto\x12\x1b\x62ilibili.app.dynamic.common\";\n\x0bItemWHRatio\x12\r\n\x05ratio\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05*Y\n\x07WHRatio\x12\x11\n\rW_H_RATIO_1_1\x10\x00\x12\x12\n\x0eW_H_RATIO_16_9\x10\x01\x12\x11\n\rW_H_RATIO_3_4\x10\x02\x12\x14\n\x10W_H_RATIO_CUSTOM\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.common.dynamic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WHRATIO']._serialized_start=135
  _globals['_WHRATIO']._serialized_end=224
  _globals['_ITEMWHRATIO']._serialized_start=74
  _globals['_ITEMWHRATIO']._serialized_end=133
# @@protoc_insertion_point(module_scope)



from typing import List, Union

from ..utils import get, post

BASE_URL = "https://api.live.bilibili.com"


async def get_rooms_info_by_uids(
    uids: List[Union[int, str]], *, auth=None, reqtype="app", **kwargs
):
    """根据 UID 批量获取直播间信息"""
    url = f"{BASE_URL}/room/v1/Room/get_status_info_by_uids"
    data = {"uids": uids}
    return await post(url, json=data, auth=auth, reqtype=reqtype, **kwargs)


async def get_rooms_info_by_ids(
    room_ids: List[Union[int, str]], *, auth=None, reqtype="app", **kwargs
):
    """根据房间号批量获取直播间信息"""
    url = f"{BASE_URL}/room/v1/Room/get_info_by_id"
    data = {"ids": room_ids}
    return await post(url, json=data, auth=auth, reqtype=reqtype, **kwargs)


async def get_room_info_by_uid(
    uid: Union[int, str], *, auth=None, reqtype="app", **kwargs
):
    """根据 UID 获取指定直播间信息"""
    url = f"{BASE_URL}/room/v1/Room/getRoomInfoOld"
    params = {"mid": uid}
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)


async def get_room_info_by_id(
    room_id: Union[int, str], *, auth=None, reqtype="app", **kwargs
):
    """根据房间号获取指定直播间信息"""
    url = f"{BASE_URL}/room/v1/Room/get_info"
    params = {"id": room_id}
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/main/common/arch/doll/v1/doll.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/main/common/arch/doll/v1/doll.proto\x12!bilibili.main.common.arch.doll.v1\":\n\x0c\x45rrorRequest\x12\r\n\x05\x65rror\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x03\"+\n\rErrorResponse\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\"\x1b\n\x0bPingRequest\x12\x0c\n\x04time\x18\x01 \x01(\x03\"*\n\x0cPingResponse\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\"\x1d\n\nSayRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\":\n\x0bSayResponse\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x32\xc1\x02\n\x04\x45\x63ho\x12g\n\x04Ping\x12..bilibili.main.common.arch.doll.v1.PingRequest\x1a/.bilibili.main.common.arch.doll.v1.PingResponse\x12\x64\n\x03Say\x12-.bilibili.main.common.arch.doll.v1.SayRequest\x1a..bilibili.main.common.arch.doll.v1.SayResponse\x12j\n\x05\x45rror\x12/.bilibili.main.common.arch.doll.v1.ErrorRequest\x1a\x30.bilibili.main.common.arch.doll.v1.ErrorResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.main.common.arch.doll.v1.doll_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ERRORREQUEST']._serialized_start=83
  _globals['_ERRORREQUEST']._serialized_end=141
  _globals['_ERRORRESPONSE']._serialized_start=143
  _globals['_ERRORRESPONSE']._serialized_end=186
  _globals['_PINGREQUEST']._serialized_start=188
  _globals['_PINGREQUEST']._serialized_end=215
  _globals['_PINGRESPONSE']._serialized_start=217
  _globals['_PINGRESPONSE']._serialized_end=259
  _globals['_SAYREQUEST']._serialized_start=261
  _globals['_SAYREQUEST']._serialized_end=290
  _globals['_SAYRESPONSE']._serialized_start=292
  _globals['_SAYRESPONSE']._serialized_end=350
  _globals['_ECHO']._serialized_start=353
  _globals['_ECHO']._serialized_end=674
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/community/service/dm/v1/dm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/community/service/dm/v1/dm.proto\x12 bilibili.community.service.dm.v1\"d\n\x06\x41vatar\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x41\n\x0b\x61vatar_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.AvatarType\"#\n\x06\x42ubble\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc6\x01\n\x08\x42ubbleV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x41\n\x0b\x62ubble_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.BubbleType\x12\x15\n\rexposure_once\x18\x04 \x01(\x08\x12\x45\n\rexposure_type\x18\x05 \x01(\x0e\x32..bilibili.community.service.dm.v1.ExposureType\"&\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"X\n\x0e\x42uzzwordConfig\x12\x46\n\x08keywords\x18\x01 \x03(\x0b\x32\x34.bilibili.community.service.dm.v1.BuzzwordShowConfig\"x\n\x12\x42uzzwordShowConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\x12\x13\n\x0b\x62uzzword_id\x18\x05 \x01(\x03\x12\x13\n\x0bschema_type\x18\x06 \x01(\x05\"{\n\x08\x43heckBox\x12\x0c\n\x04text\x18\x01 \x01(\t\x12<\n\x04type\x18\x02 \x01(\x0e\x32..bilibili.community.service.dm.v1.CheckboxType\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\x12\x0c\n\x04show\x18\x04 \x01(\x08\"?\n\nCheckBoxV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\"\x82\x02\n\x0b\x43lickButton\x12\x15\n\rportrait_text\x18\x01 \x03(\t\x12\x16\n\x0elandscape_text\x18\x02 \x03(\t\x12\x1b\n\x13portrait_text_focus\x18\x03 \x03(\t\x12\x1c\n\x14landscape_text_focus\x18\x04 \x03(\t\x12\x41\n\x0brender_type\x18\x05 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x0c\n\x04show\x18\x06 \x01(\x08\x12\x38\n\x06\x62ubble\x18\x07 \x01(\x0b\x32(.bilibili.community.service.dm.v1.Bubble\"\xd5\x01\n\rClickButtonV2\x12\x15\n\rportrait_text\x18\x01 \x03(\t\x12\x16\n\x0elandscape_text\x18\x02 \x03(\t\x12\x1b\n\x13portrait_text_focus\x18\x03 \x03(\t\x12\x1c\n\x14landscape_text_focus\x18\x04 \x03(\t\x12\x13\n\x0brender_type\x18\x05 \x01(\x05\x12\x17\n\x0ftext_input_post\x18\x06 \x01(\x08\x12\x15\n\rexposure_once\x18\x07 \x01(\x08\x12\x15\n\rexposure_type\x18\x08 \x01(\x05\"\xa1\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\r\n\x05idStr\x18\n \x01(\t\"P\n\rDanmakuAIFlag\x12?\n\x08\x64m_flags\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuFlag\"\xad\x02\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x0f\n\x07midHash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06weight\x18\t \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\n \x01(\t\x12\x0c\n\x04pool\x18\x0b \x01(\x05\x12\r\n\x05idStr\x18\x0c \x01(\t\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\x12\x11\n\tanimation\x18\x16 \x01(\t\x12\x42\n\x08\x63olorful\x18\x18 \x01(\x0e\x32\x30.bilibili.community.service.dm.v1.DmColorfulType\")\n\x0b\x44\x61nmakuFlag\x12\x0c\n\x04\x64mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\"K\n\x11\x44\x61nmakuFlagConfig\x12\x10\n\x08rec_flag\x18\x01 \x01(\x05\x12\x10\n\x08rec_text\x18\x02 \x01(\t\x12\x12\n\nrec_switch\x18\x03 \x01(\x05\"\xe4\x06\n\x18\x44\x61nmuDefaultPlayerConfig\x12)\n!player_danmaku_use_default_config\x18\x01 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12$\n\x1cinline_player_danmaku_switch\x18\x10 \x01(\x08\x12)\n!player_danmaku_senior_mode_switch\x18\x11 \x01(\x05\x12.\n&player_danmaku_ai_recommended_level_v2\x18\x12 \x01(\x05\x12\x98\x01\n*player_danmaku_ai_recommended_level_v2_map\x18\x13 \x03(\x0b\x32\x64.bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig.PlayerDanmakuAiRecommendedLevelV2MapEntry\x1aK\n)PlayerDanmakuAiRecommendedLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x8f\x08\n\x11\x44\x61nmuPlayerConfig\x12\x1d\n\x15player_danmaku_switch\x18\x01 \x01(\x08\x12\"\n\x1aplayer_danmaku_switch_save\x18\x02 \x01(\x08\x12)\n!player_danmaku_use_default_config\x18\x03 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12&\n\x1eplayer_danmaku_enableblocklist\x18\x10 \x01(\x08\x12$\n\x1cinline_player_danmaku_switch\x18\x11 \x01(\x08\x12$\n\x1cinline_player_danmaku_config\x18\x12 \x01(\x05\x12&\n\x1eplayer_danmaku_ios_switch_save\x18\x13 \x01(\x05\x12)\n!player_danmaku_senior_mode_switch\x18\x14 \x01(\x05\x12.\n&player_danmaku_ai_recommended_level_v2\x18\x15 \x01(\x05\x12\x91\x01\n*player_danmaku_ai_recommended_level_v2_map\x18\x16 \x03(\x0b\x32].bilibili.community.service.dm.v1.DanmuPlayerConfig.PlayerDanmakuAiRecommendedLevelV2MapEntry\x1aK\n)PlayerDanmakuAiRecommendedLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"0\n\x16\x44\x61nmuPlayerConfigPanel\x12\x16\n\x0eselection_text\x18\x01 \x01(\t\"K\n\x18\x44\x61nmuPlayerDynamicConfig\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\"\x90\x03\n\x15\x44\x61nmuPlayerViewConfig\x12\x61\n\x1d\x64\x61nmuku_default_player_config\x18\x01 \x01(\x0b\x32:.bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig\x12R\n\x15\x64\x61nmuku_player_config\x18\x02 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmuPlayerConfig\x12\x61\n\x1d\x64\x61nmuku_player_dynamic_config\x18\x03 \x03(\x0b\x32:.bilibili.community.service.dm.v1.DanmuPlayerDynamicConfig\x12]\n\x1b\x64\x61nmuku_player_config_panel\x18\x04 \x01(\x0b\x32\x38.bilibili.community.service.dm.v1.DanmuPlayerConfigPanel\"\xd8\x04\n\x14\x44\x61nmuWebPlayerConfig\x12\x11\n\tdm_switch\x18\x01 \x01(\x08\x12\x11\n\tai_switch\x18\x02 \x01(\x08\x12\x10\n\x08\x61i_level\x18\x03 \x01(\x05\x12\x10\n\x08\x62locktop\x18\x04 \x01(\x08\x12\x13\n\x0b\x62lockscroll\x18\x05 \x01(\x08\x12\x13\n\x0b\x62lockbottom\x18\x06 \x01(\x08\x12\x12\n\nblockcolor\x18\x07 \x01(\x08\x12\x14\n\x0c\x62lockspecial\x18\x08 \x01(\x08\x12\x14\n\x0cpreventshade\x18\t \x01(\x08\x12\r\n\x05\x64mask\x18\n \x01(\x08\x12\x0f\n\x07opacity\x18\x0b \x01(\x02\x12\x0e\n\x06\x64marea\x18\x0c \x01(\x05\x12\x11\n\tspeedplus\x18\r \x01(\x02\x12\x10\n\x08\x66ontsize\x18\x0e \x01(\x02\x12\x12\n\nscreensync\x18\x0f \x01(\x08\x12\x11\n\tspeedsync\x18\x10 \x01(\x08\x12\x12\n\nfontfamily\x18\x11 \x01(\t\x12\x0c\n\x04\x62old\x18\x12 \x01(\x08\x12\x12\n\nfontborder\x18\x13 \x01(\x05\x12\x11\n\tdraw_type\x18\x14 \x01(\t\x12\x1a\n\x12senior_mode_switch\x18\x15 \x01(\x05\x12\x13\n\x0b\x61i_level_v2\x18\x16 \x01(\x05\x12\x61\n\x0f\x61i_level_v2_map\x18\x17 \x03(\x0b\x32H.bilibili.community.service.dm.v1.DanmuWebPlayerConfig.AiLevelV2MapEntry\x1a\x33\n\x11\x41iLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"Y\n\nDmColorful\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.bilibili.community.service.dm.v1.DmColorfulType\x12\x0b\n\x03src\x18\x02 \x01(\t\"A\n\x0f\x44mExpoReportReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"\x11\n\x0f\x44mExpoReportRes\"\xe3\x0c\n\x11\x44mPlayerConfigReq\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x45\n\x06switch\x18\x02 \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuSwitch\x12N\n\x0bswitch_save\x18\x03 \x01(\x0b\x32\x39.bilibili.community.service.dm.v1.PlayerDanmakuSwitchSave\x12[\n\x12use_default_config\x18\x04 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuUseDefaultConfig\x12\x61\n\x15\x61i_recommended_switch\x18\x05 \x01(\x0b\x32\x42.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedSwitch\x12_\n\x14\x61i_recommended_level\x18\x06 \x01(\x0b\x32\x41.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevel\x12I\n\x08\x62locktop\x18\x07 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.PlayerDanmakuBlocktop\x12O\n\x0b\x62lockscroll\x18\x08 \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockscroll\x12O\n\x0b\x62lockbottom\x18\t \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockbottom\x12S\n\rblockcolorful\x18\n \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuBlockcolorful\x12O\n\x0b\x62lockrepeat\x18\x0b \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockrepeat\x12Q\n\x0c\x62lockspecial\x18\x0c \x01(\x0b\x32;.bilibili.community.service.dm.v1.PlayerDanmakuBlockspecial\x12G\n\x07opacity\x18\r \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.PlayerDanmakuOpacity\x12S\n\rscalingfactor\x18\x0e \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuScalingfactor\x12\x45\n\x06\x64omain\x18\x0f \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuDomain\x12\x43\n\x05speed\x18\x10 \x01(\x0b\x32\x34.bilibili.community.service.dm.v1.PlayerDanmakuSpeed\x12W\n\x0f\x65nableblocklist\x18\x11 \x01(\x0b\x32>.bilibili.community.service.dm.v1.PlayerDanmakuEnableblocklist\x12^\n\x19inlinePlayerDanmakuSwitch\x18\x12 \x01(\x0b\x32;.bilibili.community.service.dm.v1.InlinePlayerDanmakuSwitch\x12[\n\x12senior_mode_switch\x18\x13 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuSeniorModeSwitch\x12\x64\n\x17\x61i_recommended_level_v2\x18\x14 \x01(\x0b\x32\x43.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevelV2\"/\n\x0b\x44mSegConfig\x12\x11\n\tpage_size\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"\xe4\x01\n\x10\x44mSegMobileReply\x12<\n\x05\x65lems\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\x12\r\n\x05state\x18\x02 \x01(\x05\x12@\n\x07\x61i_flag\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.DanmakuAIFlag\x12\x41\n\x0b\x63olorfulSrc\x18\x05 \x03(\x0b\x32,.bilibili.community.service.dm.v1.DmColorful\"\xa6\x01\n\x0e\x44mSegMobileReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x05 \x01(\x05\x12\n\n\x02ps\x18\x06 \x01(\x03\x12\n\n\x02pe\x18\x07 \x01(\x03\x12\x11\n\tpull_mode\x18\x08 \x01(\x05\x12\x12\n\nfrom_scene\x18\t \x01(\x05\"]\n\rDmSegOttReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegOttReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"]\n\rDmSegSDKReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegSDKReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"\xde\x06\n\x0b\x44mViewReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x39\n\x04mask\x18\x02 \x01(\x0b\x32+.bilibili.community.service.dm.v1.VideoMask\x12\x41\n\x08subtitle\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.VideoSubtitle\x12\x13\n\x0bspecial_dms\x18\x04 \x03(\t\x12\x44\n\x07\x61i_flag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12N\n\rplayer_config\x18\x06 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.DanmuPlayerViewConfig\x12\x16\n\x0esend_box_style\x18\x07 \x01(\x05\x12\r\n\x05\x61llow\x18\x08 \x01(\x08\x12\x11\n\tcheck_box\x18\t \x01(\t\x12\x1a\n\x12\x63heck_box_show_msg\x18\n \x01(\t\x12\x18\n\x10text_placeholder\x18\x0b \x01(\t\x12\x19\n\x11input_placeholder\x18\x0c \x01(\t\x12\x1d\n\x15report_filter_content\x18\r \x03(\t\x12\x41\n\x0b\x65xpo_report\x18\x0e \x01(\x0b\x32,.bilibili.community.service.dm.v1.ExpoReport\x12I\n\x0f\x62uzzword_config\x18\x0f \x01(\x0b\x32\x30.bilibili.community.service.dm.v1.BuzzwordConfig\x12\x42\n\x0b\x65xpressions\x18\x10 \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\x12?\n\npost_panel\x18\x11 \x03(\x0b\x32+.bilibili.community.service.dm.v1.PostPanel\x12\x15\n\ractivity_meta\x18\x12 \x03(\t\x12\x42\n\x0bpost_panel2\x18\x13 \x03(\x0b\x32-.bilibili.community.service.dm.v1.PostPanelV2\"X\n\tDmViewReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x14\n\x0cis_hard_boot\x18\x05 \x01(\x05\"\xc4\x04\n\x0e\x44mWebViewReply\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\ttext_side\x18\x03 \x01(\t\x12=\n\x06\x64m_sge\x18\x04 \x01(\x0b\x32-.bilibili.community.service.dm.v1.DmSegConfig\x12\x41\n\x04\x66lag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12\x13\n\x0bspecial_dms\x18\x06 \x03(\t\x12\x11\n\tcheck_box\x18\x07 \x01(\x08\x12\r\n\x05\x63ount\x18\x08 \x01(\x03\x12?\n\ncommandDms\x18\t \x03(\x0b\x32+.bilibili.community.service.dm.v1.CommandDm\x12M\n\rplayer_config\x18\n \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.DanmuWebPlayerConfig\x12\x1d\n\x15report_filter_content\x18\x0b \x03(\t\x12\x42\n\x0b\x65xpressions\x18\x0c \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\x12?\n\npost_panel\x18\r \x03(\x0b\x32+.bilibili.community.service.dm.v1.PostPanel\x12\x15\n\ractivity_meta\x18\x0e \x03(\t\"*\n\nExpoReport\x12\x1c\n\x14should_report_at_end\x18\x01 \x01(\x08\"d\n\nExpression\x12\x0f\n\x07keyword\x18\x01 \x03(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x38\n\x06period\x18\x03 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Period\"I\n\x0b\x45xpressions\x12:\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32,.bilibili.community.service.dm.v1.Expression\"*\n\x19InlinePlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\"\'\n\x05Label\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\"W\n\x07LabelV2\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\x12\x15\n\rexposure_once\x18\x03 \x01(\x08\x12\x15\n\rexposure_type\x18\x04 \x01(\x05\"$\n\x06Period\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"0\n\x1fPlayerDanmakuAiRecommendedLevel\x12\r\n\x05value\x18\x01 \x01(\x08\"2\n!PlayerDanmakuAiRecommendedLevelV2\x12\r\n\x05value\x18\x01 \x01(\x05\"1\n PlayerDanmakuAiRecommendedSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockbottom\x12\r\n\x05value\x18\x01 \x01(\x08\"+\n\x1aPlayerDanmakuBlockcolorful\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockrepeat\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockscroll\x12\r\n\x05value\x18\x01 \x01(\x08\"*\n\x19PlayerDanmakuBlockspecial\x12\r\n\x05value\x18\x01 \x01(\x08\"&\n\x15PlayerDanmakuBlocktop\x12\r\n\x05value\x18\x01 \x01(\x08\"$\n\x13PlayerDanmakuDomain\x12\r\n\x05value\x18\x01 \x01(\x02\"-\n\x1cPlayerDanmakuEnableblocklist\x12\r\n\x05value\x18\x01 \x01(\x08\"%\n\x14PlayerDanmakuOpacity\x12\r\n\x05value\x18\x01 \x01(\x02\"+\n\x1aPlayerDanmakuScalingfactor\x12\r\n\x05value\x18\x01 \x01(\x02\".\n\x1dPlayerDanmakuSeniorModeSwitch\x12\r\n\x05value\x18\x01 \x01(\x05\"#\n\x12PlayerDanmakuSpeed\x12\r\n\x05value\x18\x01 \x01(\x05\"8\n\x13PlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x12\n\ncan_ignore\x18\x02 \x01(\x08\"(\n\x17PlayerDanmakuSwitchSave\x12\r\n\x05value\x18\x01 \x01(\x08\".\n\x1dPlayerDanmakuUseDefaultConfig\x12\r\n\x05value\x18\x01 \x01(\x08\"\x8c\x03\n\tPostPanel\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\x12\x10\n\x08priority\x18\x03 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x04 \x01(\x03\x12\x44\n\x08\x62iz_type\x18\x05 \x01(\x0e\x32\x32.bilibili.community.service.dm.v1.PostPanelBizType\x12\x43\n\x0c\x63lick_button\x18\x06 \x01(\x0b\x32-.bilibili.community.service.dm.v1.ClickButton\x12?\n\ntext_input\x18\x07 \x01(\x0b\x32+.bilibili.community.service.dm.v1.TextInput\x12=\n\tcheck_box\x18\x08 \x01(\x0b\x32*.bilibili.community.service.dm.v1.CheckBox\x12\x36\n\x05toast\x18\t \x01(\x0b\x32\'.bilibili.community.service.dm.v1.Toast\"\xcb\x03\n\x0bPostPanelV2\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x03 \x01(\x05\x12\x45\n\x0c\x63lick_button\x18\x04 \x01(\x0b\x32/.bilibili.community.service.dm.v1.ClickButtonV2\x12\x41\n\ntext_input\x18\x05 \x01(\x0b\x32-.bilibili.community.service.dm.v1.TextInputV2\x12?\n\tcheck_box\x18\x06 \x01(\x0b\x32,.bilibili.community.service.dm.v1.CheckBoxV2\x12\x38\n\x05toast\x18\x07 \x01(\x0b\x32).bilibili.community.service.dm.v1.ToastV2\x12:\n\x06\x62ubble\x18\x08 \x01(\x0b\x32*.bilibili.community.service.dm.v1.BubbleV2\x12\x38\n\x05label\x18\t \x01(\x0b\x32).bilibili.community.service.dm.v1.LabelV2\x12\x13\n\x0bpost_status\x18\n \x01(\x05\")\n\x08Response\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf9\x02\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06id_str\x18\x02 \x01(\t\x12\x0b\n\x03lan\x18\x03 \x01(\t\x12\x0f\n\x07lan_doc\x18\x04 \x01(\t\x12\x14\n\x0csubtitle_url\x18\x05 \x01(\t\x12:\n\x06\x61uthor\x18\x06 \x01(\x0b\x32*.bilibili.community.service.dm.v1.UserInfo\x12<\n\x04type\x18\x07 \x01(\x0e\x32..bilibili.community.service.dm.v1.SubtitleType\x12\x15\n\rlan_doc_brief\x18\x08 \x01(\t\x12\x41\n\x07\x61i_type\x18\t \x01(\x0e\x32\x30.bilibili.community.service.dm.v1.SubtitleAiType\x12\x45\n\tai_status\x18\n \x01(\x0e\x32\x32.bilibili.community.service.dm.v1.SubtitleAiStatus\"\xe8\x02\n\tTextInput\x12\x1c\n\x14portrait_placeholder\x18\x01 \x03(\t\x12\x1d\n\x15landscape_placeholder\x18\x02 \x03(\t\x12\x41\n\x0brender_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x18\n\x10placeholder_post\x18\x04 \x01(\x08\x12\x0c\n\x04show\x18\x05 \x01(\x08\x12\x38\n\x06\x61vatar\x18\x06 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Avatar\x12\x41\n\x0bpost_status\x18\x07 \x01(\x0e\x32,.bilibili.community.service.dm.v1.PostStatus\x12\x36\n\x05label\x18\x08 \x01(\x0b\x32\'.bilibili.community.service.dm.v1.Label\"\xfb\x01\n\x0bTextInputV2\x12\x1c\n\x14portrait_placeholder\x18\x01 \x03(\t\x12\x1d\n\x15landscape_placeholder\x18\x02 \x03(\t\x12\x41\n\x0brender_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x18\n\x10placeholder_post\x18\x04 \x01(\x08\x12\x38\n\x06\x61vatar\x18\x05 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Avatar\x12\x18\n\x10text_input_limit\x18\x06 \x01(\x05\"o\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x0c\n\x04show\x18\x03 \x01(\x08\x12\x38\n\x06\x62utton\x18\x04 \x01(\x0b\x32(.bilibili.community.service.dm.v1.Button\"-\n\rToastButtonV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"s\n\x07ToastV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12H\n\x0ftoast_button_v2\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.ToastButtonV2\"\\\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0c\n\x04rank\x18\x06 \x01(\x05\"S\n\tVideoMask\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\x0b\n\x03\x66ps\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x10\n\x08mask_url\x18\x05 \x01(\t\"o\n\rVideoSubtitle\x12\x0b\n\x03lan\x18\x01 \x01(\t\x12\x0e\n\x06lanDoc\x18\x02 \x01(\t\x12\x41\n\tsubtitles\x18\x03 \x03(\x0b\x32..bilibili.community.service.dm.v1.SubtitleItem*3\n\nAvatarType\x12\x12\n\x0e\x41vatarTypeNone\x10\x00\x12\x11\n\rAvatarTypeNFT\x10\x01*Y\n\nBubbleType\x12\x12\n\x0e\x42ubbleTypeNone\x10\x00\x12\x19\n\x15\x42ubbleTypeClickButton\x10\x01\x12\x1c\n\x18\x42ubbleTypeDmSettingPanel\x10\x02*X\n\x0c\x43heckboxType\x12\x14\n\x10\x43heckboxTypeNone\x10\x00\x12\x19\n\x15\x43heckboxTypeEncourage\x10\x01\x12\x17\n\x13\x43heckboxTypeColorDM\x10\x02*L\n\tDMAttrBit\x12\x14\n\x10\x44MAttrBitProtect\x10\x00\x12\x15\n\x11\x44MAttrBitFromLive\x10\x01\x12\x12\n\x0e\x44MAttrHighLike\x10\x02*5\n\x0e\x44mColorfulType\x12\x0c\n\x08NoneType\x10\x00\x12\x15\n\x0fVipGradualColor\x10\xe1\xd4\x03*<\n\x0c\x45xposureType\x12\x14\n\x10\x45xposureTypeNone\x10\x00\x12\x16\n\x12\x45xposureTypeDMSend\x10\x01*\xc1\x01\n\x10PostPanelBizType\x12\x18\n\x14PostPanelBizTypeNone\x10\x00\x12\x1d\n\x19PostPanelBizTypeEncourage\x10\x01\x12\x1b\n\x17PostPanelBizTypeColorDM\x10\x02\x12\x19\n\x15PostPanelBizTypeNFTDM\x10\x03\x12\x1d\n\x19PostPanelBizTypeFragClose\x10\x04\x12\x1d\n\x19PostPanelBizTypeRecommend\x10\x05*8\n\nPostStatus\x12\x14\n\x10PostStatusNormal\x10\x00\x12\x14\n\x10PostStatusClosed\x10\x01*N\n\nRenderType\x12\x12\n\x0eRenderTypeNone\x10\x00\x12\x14\n\x10RenderTypeSingle\x10\x01\x12\x16\n\x12RenderTypeRotation\x10\x02*6\n\x10SubtitleAiStatus\x12\x08\n\x04None\x10\x00\x12\x0c\n\x08\x45xposure\x10\x01\x12\n\n\x06\x41ssist\x10\x02*+\n\x0eSubtitleAiType\x12\n\n\x06Normal\x10\x00\x12\r\n\tTranslate\x10\x01*\x1e\n\x0cSubtitleType\x12\x06\n\x02\x43\x43\x10\x00\x12\x06\n\x02\x41I\x10\x01*N\n\x11ToastFunctionType\x12\x19\n\x15ToastFunctionTypeNone\x10\x00\x12\x1e\n\x1aToastFunctionTypePostPanel\x10\x01\x32\xa0\x05\n\x02\x44M\x12s\n\x0b\x44mSegMobile\x12\x30.bilibili.community.service.dm.v1.DmSegMobileReq\x1a\x32.bilibili.community.service.dm.v1.DmSegMobileReply\x12\x64\n\x06\x44mView\x12+.bilibili.community.service.dm.v1.DmViewReq\x1a-.bilibili.community.service.dm.v1.DmViewReply\x12q\n\x0e\x44mPlayerConfig\x12\x33.bilibili.community.service.dm.v1.DmPlayerConfigReq\x1a*.bilibili.community.service.dm.v1.Response\x12j\n\x08\x44mSegOtt\x12-.bilibili.community.service.dm.v1.DmSegOttReq\x1a/.bilibili.community.service.dm.v1.DmSegOttReply\x12j\n\x08\x44mSegSDK\x12-.bilibili.community.service.dm.v1.DmSegSDKReq\x1a/.bilibili.community.service.dm.v1.DmSegSDKReply\x12t\n\x0c\x44mExpoReport\x12\x31.bilibili.community.service.dm.v1.DmExpoReportReq\x1a\x31.bilibili.community.service.dm.v1.DmExpoReportResb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.community.service.dm.v1.dm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._options = None
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_options = b'8\001'
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._options = None
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_options = b'8\001'
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._options = None
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._serialized_options = b'8\001'
  _globals['_AVATARTYPE']._serialized_start=12918
  _globals['_AVATARTYPE']._serialized_end=12969
  _globals['_BUBBLETYPE']._serialized_start=12971
  _globals['_BUBBLETYPE']._serialized_end=13060
  _globals['_CHECKBOXTYPE']._serialized_start=13062
  _globals['_CHECKBOXTYPE']._serialized_end=13150
  _globals['_DMATTRBIT']._serialized_start=13152
  _globals['_DMATTRBIT']._serialized_end=13228
  _globals['_DMCOLORFULTYPE']._serialized_start=13230
  _globals['_DMCOLORFULTYPE']._serialized_end=13283
  _globals['_EXPOSURETYPE']._serialized_start=13285
  _globals['_EXPOSURETYPE']._serialized_end=13345
  _globals['_POSTPANELBIZTYPE']._serialized_start=13348
  _globals['_POSTPANELBIZTYPE']._serialized_end=13541
  _globals['_POSTSTATUS']._serialized_start=13543
  _globals['_POSTSTATUS']._serialized_end=13599
  _globals['_RENDERTYPE']._serialized_start=13601
  _globals['_RENDERTYPE']._serialized_end=13679
  _globals['_SUBTITLEAISTATUS']._serialized_start=13681
  _globals['_SUBTITLEAISTATUS']._serialized_end=13735
  _globals['_SUBTITLEAITYPE']._serialized_start=13737
  _globals['_SUBTITLEAITYPE']._serialized_end=13780
  _globals['_SUBTITLETYPE']._serialized_start=13782
  _globals['_SUBTITLETYPE']._serialized_end=13812
  _globals['_TOASTFUNCTIONTYPE']._serialized_start=13814
  _globals['_TOASTFUNCTIONTYPE']._serialized_end=13892
  _globals['_AVATAR']._serialized_start=79
  _globals['_AVATAR']._serialized_end=179
  _globals['_BUBBLE']._serialized_start=181
  _globals['_BUBBLE']._serialized_end=216
  _globals['_BUBBLEV2']._serialized_start=219
  _globals['_BUBBLEV2']._serialized_end=417
  _globals['_BUTTON']._serialized_start=419
  _globals['_BUTTON']._serialized_end=457
  _globals['_BUZZWORDCONFIG']._serialized_start=459
  _globals['_BUZZWORDCONFIG']._serialized_end=547
  _globals['_BUZZWORDSHOWCONFIG']._serialized_start=549
  _globals['_BUZZWORDSHOWCONFIG']._serialized_end=669
  _globals['_CHECKBOX']._serialized_start=671
  _globals['_CHECKBOX']._serialized_end=794
  _globals['_CHECKBOXV2']._serialized_start=796
  _globals['_CHECKBOXV2']._serialized_end=859
  _globals['_CLICKBUTTON']._serialized_start=862
  _globals['_CLICKBUTTON']._serialized_end=1120
  _globals['_CLICKBUTTONV2']._serialized_start=1123
  _globals['_CLICKBUTTONV2']._serialized_end=1336
  _globals['_COMMANDDM']._serialized_start=1339
  _globals['_COMMANDDM']._serialized_end=1500
  _globals['_DANMAKUAIFLAG']._serialized_start=1502
  _globals['_DANMAKUAIFLAG']._serialized_end=1582
  _globals['_DANMAKUELEM']._serialized_start=1585
  _globals['_DANMAKUELEM']._serialized_end=1886
  _globals['_DANMAKUFLAG']._serialized_start=1888
  _globals['_DANMAKUFLAG']._serialized_end=1929
  _globals['_DANMAKUFLAGCONFIG']._serialized_start=1931
  _globals['_DANMAKUFLAGCONFIG']._serialized_end=2006
  _globals['_DANMUDEFAULTPLAYERCONFIG']._serialized_start=2009
  _globals['_DANMUDEFAULTPLAYERCONFIG']._serialized_end=2877
  _globals['_DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY']._serialized_start=2802
  _globals['_DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY']._serialized_end=2877
  _globals['_DANMUPLAYERCONFIG']._serialized_start=2880
  _globals['_DANMUPLAYERCONFIG']._serialized_end=3919
  _globals['_DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY']._serialized_start=2802
  _globals['_DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY']._serialized_end=2877
  _globals['_DANMUPLAYERCONFIGPANEL']._serialized_start=3921
  _globals['_DANMUPLAYERCONFIGPANEL']._serialized_end=3969
  _globals['_DANMUPLAYERDYNAMICCONFIG']._serialized_start=3971
  _globals['_DANMUPLAYERDYNAMICCONFIG']._serialized_end=4046
  _globals['_DANMUPLAYERVIEWCONFIG']._serialized_start=4049
  _globals['_DANMUPLAYERVIEWCONFIG']._serialized_end=4449
  _globals['_DANMUWEBPLAYERCONFIG']._serialized_start=4452
  _globals['_DANMUWEBPLAYERCONFIG']._serialized_end=5052
  _globals['_DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY']._serialized_start=5001
  _globals['_DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY']._serialized_end=5052
  _globals['_DMCOLORFUL']._serialized_start=5054
  _globals['_DMCOLORFUL']._serialized_end=5143
  _globals['_DMEXPOREPORTREQ']._serialized_start=5145
  _globals['_DMEXPOREPORTREQ']._serialized_end=5210
  _globals['_DMEXPOREPORTRES']._serialized_start=5212
  _globals['_DMEXPOREPORTRES']._serialized_end=5229
  _globals['_DMPLAYERCONFIGREQ']._serialized_start=5232
  _globals['_DMPLAYERCONFIGREQ']._serialized_end=6867
  _globals['_DMSEGCONFIG']._serialized_start=6869
  _globals['_DMSEGCONFIG']._serialized_end=6916
  _globals['_DMSEGMOBILEREPLY']._serialized_start=6919
  _globals['_DMSEGMOBILEREPLY']._serialized_end=7147
  _globals['_DMSEGMOBILEREQ']._serialized_start=7150
  _globals['_DMSEGMOBILEREQ']._serialized_end=7316
  _globals['_DMSEGOTTREPLY']._serialized_start=7318
  _globals['_DMSEGOTTREPLY']._serialized_end=7411
  _globals['_DMSEGOTTREQ']._serialized_start=7413
  _globals['_DMSEGOTTREQ']._serialized_end=7489
  _globals['_DMSEGSDKREPLY']._serialized_start=7491
  _globals['_DMSEGSDKREPLY']._serialized_end=7584
  _globals['_DMSEGSDKREQ']._serialized_start=7586
  _globals['_DMSEGSDKREQ']._serialized_end=7662
  _globals['_DMVIEWREPLY']._serialized_start=7665
  _globals['_DMVIEWREPLY']._serialized_end=8527
  _globals['_DMVIEWREQ']._serialized_start=8529
  _globals['_DMVIEWREQ']._serialized_end=8617
  _globals['_DMWEBVIEWREPLY']._serialized_start=8620
  _globals['_DMWEBVIEWREPLY']._serialized_end=9200
  _globals['_EXPOREPORT']._serialized_start=9202
  _globals['_EXPOREPORT']._serialized_end=9244
  _globals['_EXPRESSION']._serialized_start=9246
  _globals['_EXPRESSION']._serialized_end=9346
  _globals['_EXPRESSIONS']._serialized_start=9348
  _globals['_EXPRESSIONS']._serialized_end=9421
  _globals['_INLINEPLAYERDANMAKUSWITCH']._serialized_start=9423
  _globals['_INLINEPLAYERDANMAKUSWITCH']._serialized_end=9465
  _globals['_LABEL']._serialized_start=9467
  _globals['_LABEL']._serialized_end=9506
  _globals['_LABELV2']._serialized_start=9508
  _globals['_LABELV2']._serialized_end=9595
  _globals['_PERIOD']._serialized_start=9597
  _globals['_PERIOD']._serialized_end=9633
  _globals['_PLAYERDANMAKUAIRECOMMENDEDLEVEL']._serialized_start=9635
  _globals['_PLAYERDANMAKUAIRECOMMENDEDLEVEL']._serialized_end=9683
  _globals['_PLAYERDANMAKUAIRECOMMENDEDLEVELV2']._serialized_start=9685
  _globals['_PLAYERDANMAKUAIRECOMMENDEDLEVELV2']._serialized_end=9735
  _globals['_PLAYERDANMAKUAIRECOMMENDEDSWITCH']._serialized_start=9737
  _globals['_PLAYERDANMAKUAIRECOMMENDEDSWITCH']._serialized_end=9786
  _globals['_PLAYERDANMAKUBLOCKBOTTOM']._serialized_start=9788
  _globals['_PLAYERDANMAKUBLOCKBOTTOM']._serialized_end=9829
  _globals['_PLAYERDANMAKUBLOCKCOLORFUL']._serialized_start=9831
  _globals['_PLAYERDANMAKUBLOCKCOLORFUL']._serialized_end=9874
  _globals['_PLAYERDANMAKUBLOCKREPEAT']._serialized_start=9876
  _globals['_PLAYERDANMAKUBLOCKREPEAT']._serialized_end=9917
  _globals['_PLAYERDANMAKUBLOCKSCROLL']._serialized_start=9919
  _globals['_PLAYERDANMAKUBLOCKSCROLL']._serialized_end=9960
  _globals['_PLAYERDANMAKUBLOCKSPECIAL']._serialized_start=9962
  _globals['_PLAYERDANMAKUBLOCKSPECIAL']._serialized_end=10004
  _globals['_PLAYERDANMAKUBLOCKTOP']._serialized_start=10006
  _globals['_PLAYERDANMAKUBLOCKTOP']._serialized_end=10044
  _globals['_PLAYERDANMAKUDOMAIN']._serialized_start=10046
  _globals['_PLAYERDANMAKUDOMAIN']._serialized_end=10082
  _globals['_PLAYERDANMAKUENABLEBLOCKLIST']._serialized_start=10084
  _globals['_PLAYERDANMAKUENABLEBLOCKLIST']._serialized_end=10129
  _globals['_PLAYERDANMAKUOPACITY']._serialized_start=10131
  _globals['_PLAYERDANMAKUOPACITY']._serialized_end=10168
  _globals['_PLAYERDANMAKUSCALINGFACTOR']._serialized_start=10170
  _globals['_PLAYERDANMAKUSCALINGFACTOR']._serialized_end=10213
  _globals['_PLAYERDANMAKUSENIORMODESWITCH']._serialized_start=10215
  _globals['_PLAYERDANMAKUSENIORMODESWITCH']._serialized_end=10261
  _globals['_PLAYERDANMAKUSPEED']._serialized_start=10263
  _globals['_PLAYERDANMAKUSPEED']._serialized_end=10298
  _globals['_PLAYERDANMAKUSWITCH']._serialized_start=10300
  _globals['_PLAYERDANMAKUSWITCH']._serialized_end=10356
  _globals['_PLAYERDANMAKUSWITCHSAVE']._serialized_start=10358
  _globals['_PLAYERDANMAKUSWITCHSAVE']._serialized_end=10398
  _globals['_PLAYERDANMAKUUSEDEFAULTCONFIG']._serialized_start=10400
  _globals['_PLAYERDANMAKUUSEDEFAULTCONFIG']._serialized_end=10446
  _globals['_POSTPANEL']._serialized_start=10449
  _globals['_POSTPANEL']._serialized_end=10845
  _globals['_POSTPANELV2']._serialized_start=10848
  _globals['_POSTPANELV2']._serialized_end=11307
  _globals['_RESPONSE']._serialized_start=11309
  _globals['_RESPONSE']._serialized_end=11350
  _globals['_SUBTITLEITEM']._serialized_start=11353
  _globals['_SUBTITLEITEM']._serialized_end=11730
  _globals['_TEXTINPUT']._serialized_start=11733
  _globals['_TEXTINPUT']._serialized_end=12093
  _globals['_TEXTINPUTV2']._serialized_start=12096
  _globals['_TEXTINPUTV2']._serialized_end=12347
  _globals['_TOAST']._serialized_start=12349
  _globals['_TOAST']._serialized_end=12460
  _globals['_TOASTBUTTONV2']._serialized_start=12462
  _globals['_TOASTBUTTONV2']._serialized_end=12507
  _globals['_TOASTV2']._serialized_start=12509
  _globals['_TOASTV2']._serialized_end=12624
  _globals['_USERINFO']._serialized_start=12626
  _globals['_USERINFO']._serialized_end=12718
  _globals['_VIDEOMASK']._serialized_start=12720
  _globals['_VIDEOMASK']._serialized_end=12803
  _globals['_VIDEOSUBTITLE']._serialized_start=12805
  _globals['_VIDEOSUBTITLE']._serialized_end=12916
  _globals['_DM']._serialized_start=13895
  _globals['_DM']._serialized_end=14567
# @@protoc_insertion_point(module_scope)
